<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  96611 => 'الرياض/الخرج',
  96612 => 'مكة/جدة',
  96613 => 'الدمام/الخبر/الظهران',
  96614 => 'المدينة المنورة/عرعر/تبوك/ينبع البحر',
  96616 => 'حائل/القصيم',
  96617 => 'أبها/نجران/جازان',
);
