<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'FR' => 'Fransa',
  'IT' => 'Italia',
  'MC' => 'Monego',
);
